==> gtag_interop-0.1.0.tar.gz: doc/usage/advanced.md <==
## IP anonymization
In some cases, you might need to anonymize the IP addresses of hits sent to Google Analytics.

### For all events
TODO

```dart
import 'package:gtag_interop/gtag_interop.dart.dart';

void main() => new Analytics('GA_TRACKING_ID')..anonymizeIP();
```

### For a single event
TODO

```dart
import 'package:gtag_interop/gtag_interop.dart.dart';

void main() => new Analytics('GA_TRACKING_ID')
  ..configure()
  ..sendEvent('your_event', Parameters(anonymize_ip: true));
```

## Rename the global object
TODO

## Disable tracking
In some cases, it may be necessary to disable the tracking on a page without removing the `gtag.js` tracking snippet. For example, you might do this if your site's privacy policy provides an option for the user to opt-out of the tracking.

The `Analytics` class includes an `enabled` property that, when set to `true`, disables `gtag.js` from sending data to Google Analytics. When Google Analytics attempts to set a cookie or send data back to the Google Analytics servers, it will first check if this property is set, and will take no action if the value is set to `true`.

To disable tracking, set the `enabled` property to `true`:

```dart
import 'package:gtag_interop/gtag_interop.dart.dart';

void main() => new Analytics('GA_TRACKING_ID')
  ..enabled = false
  ..configure();
```

!!! warning
    The `Analytics.enabled` property must be set before any calls to `gtag()`
    or `Analytics.configure()` are made, and it must be set on each page
    for which you want to disable the tracking.
    If the property is not set or set to `false`, then tracking will work as usual.

==> gtag_interop-0.2.0.tar.gz: doc/usage/advanced.md <==
## IP anonymization
In some cases, you might need to anonymize the IP addresses of hits sent to Google Analytics.

### For all events
TODO

```dart
import 'package:gtag_interop/gtag_interop.dart.dart';

void main() => Analytics('GA_TRACKING_ID')..anonymizeIP();
```

### For a single event
TODO

```dart
import 'package:gtag_interop/gtag_interop.dart.dart';

void main() => Analytics('GA_TRACKING_ID')..configure()
  ..sendEvent('your_event', Parameters(anonymize_ip: true));
```

## Rename the global object
TODO

## Disable tracking
In some cases, it may be necessary to disable the tracking on a page without removing the `gtag.js` tracking snippet. For example, you might do this if your site's privacy policy provides an option for the user to opt-out of the tracking.

The `Analytics` class includes an `enabled` property that, when set to `true`, disables `gtag.js` from sending data to Google Analytics. When Google Analytics attempts to set a cookie or send data back to the Google Analytics servers, it will first check if this property is set, and will take no action if the value is set to `true`.

To disable tracking, set the `enabled` property to `true`:

```dart
import 'package:gtag_interop/gtag_interop.dart.dart';

void main() => Analytics('GA_TRACKING_ID')
  ..enabled = false
  ..configure();
```

!!! warning
    The `Analytics.enabled` property must be set before any calls to `gtag()`
    or `Analytics.configure()` are made. If the property is not set
    or set to `false`, then tracking will work as usual.
